//
//  SIDAPI.h
//  SocialID
//
//  Created by Renato Neves on 2/7/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import "SIDRequest.h"

typedef void (^SIDAPIFailureHandler)(NSError *error);

@interface SIDAPI : NSObject

/**
 The HTTP Client responsible to perform the request operations.
 */
@property SIDRequest *httpClient;

/**
 Returns a SocialID API client.
 @return A SIDAPI instance.
 */
+ (instancetype) client;

/**
 Returns a SocialID API client with OAuth2 Bearer authorization token initialized.
 @param token The OAuth2 Bearer token
 */
+ (instancetype) clientWithToken:(NSString *)token;

/**
 Sets the API base url.
 */
+ (void) setBaseUrl:(NSString *)url;

/**
 Returns the API base url.
 @return A string url.
 */
- (NSString *) getBaseUrl;

/**
 Add authorization headers for a Social Login Client Application.
 Requires the Social Login Client Application be defined on SocialID SDK initialization.
 */
- (void) useApplicationClientAuth;

/**
 Add authorization headers for a User OAuth2 Bearer token.
 Requires the presence of a user token in the SIDDefaults (it's automatically filled when a user token is created).
 */
- (void) useLoginUserTokenAuth;

/**
 Add authorization headers for a Login App OAuth2 Bearer token.
 Requires the presence of a login app token in the SIDDefaults (it's automatically filled when a login app token is created).
 */
- (void) useLoginAppTokenAuth;

/**
 Add authorization headers for OAuth2 Bearer token.
 @param token The OAuth2 Bearer token
 */
- (void) useOAuthTokenAuth:(NSString *)token;

@end
