//
//  SIDAPIOAuth.h
//  SocialID
//
//  Created by Renato Neves on 9/10/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import "SIDAPI.h"
#import "SIDToken.h"

@interface SIDAPIOAuth : SIDAPI

/**
 Creates a new OAuth2 login app token.
 It also sets the login app token in the session.
 @see http://dev.socialidnow.com/index.php/POST_/oauth/token_client_credentials
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDToken object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) createAppToken:(void (^)(SIDToken *))success
                failure:(SIDAPIFailureHandler)failure;

/**
 Creates a new OAuth2 user token given a provider access token.
 It also sets the login user token in the session.
 @see http://dev.socialidnow.com/index.php/POST_/oauth/token_provider_credentials
 @param provider The social network.
 @param accessToken The user credential access token provided by the social network.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDToken object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) createUserToken:(NSString *)provider
             accessToken:(NSString *)accessToken
                 success:(void (^)(SIDToken *))success
                 failure:(SIDAPIFailureHandler)failure;

/**
 Creates a new OAuth2 user token given a provider access token and access secret.
 It also sets the login user token in the session.
 @see http://dev.socialidnow.com/index.php/POST_/oauth/token_provider_credentials
 @param provider The social network.
 @param accessToken The user credential access token provided by the social network.
 @param accessSecret The user credential access secret provided by the social network.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDToken object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) createUserToken:(NSString *)provider
             accessToken:(NSString *)accessToken
            accessSecret:(NSString *)accessSecret
                 success:(void (^)(SIDToken *))success
                 failure:(SIDAPIFailureHandler)failure;

/**
 Creates a new OAuth2 user token given a username or e-mail and a password.
 It also sets the login user token in the session.
 @see http://dev.socialidnow.com/index.php/POST_/oauth/token_provider_credentials
 @param username The chosen username. Optional.
 @param email The user's e-mail. Optional. Exactly one of the optional fields must be given.
 @param password The user's password.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDToken object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) createUserToken:(NSString *)username
                   email:(NSString *)email
                   password:(NSString *)password
                 success:(void (^)(SIDToken *))success
                 failure:(SIDAPIFailureHandler)failure;

/**
 Creates a new OAuth2 token given a refresh access token.
 It also sets the login user token in the session.
 @see http://dev.socialidnow.com/index.php/POST_/oauth/token_refresh_token
 @param refreshToken The refresh token.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDToken object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) refreshUserToken:(NSString *)refreshToken
                  success:(void (^)(SIDToken *))success
                  failure:(SIDAPIFailureHandler)failure;

@end
