//
//  SIDAPIUser.h
//  SocialID
//
//  Created by Renato Neves on 9/10/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import "SIDAPI.h"
#import "SIDUser.h"

@interface SIDAPIUser : SIDAPI

/**
 Retrieve user information defined by fields for a given user id.
 @see http://dev.socialidnow.com/index.php/GET_/oauth/login/user
 @param userToken The user token.
 @param fields A comma separated list of user information to be retrieved. See API documentation for the available fields.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDUser object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) getUser:(NSString *)fields
         success:(void (^)(SIDUser *))success
         failure:(SIDAPIFailureHandler)failure;

/**
 Retrieve user information defined by fields for a given user id.
 @see http://dev.socialidnow.com/index.php/GET_/oauth/login/user
 @param userToken The user token.
 @param success A block object to be executed when the request operation finished successfully. The block object takes the SIDUser object created as an argument.
 @param failure A block object to be executed when the request operation finishes unsuccessfully. The block object takes the error object as an argument.
 */
- (void) getUser:(void (^)(SIDUser *))success
         failure:(SIDAPIFailureHandler)failure;

/**
 Create a new user using given information.
 @see http://dev.socialidnow.com/index.php/POST_oauth/login/users
 @param username Optional new username.
 @param email Optional e-mail password. At least one of the optional fields must be given.
 @param password New password
 */
- (void) createUser:(NSString *)username
              email:(NSString *)email
           password:(NSString *)password
            success:(void (^)(void))success
            failure:(SIDAPIFailureHandler)failure;

/**
 Sends a reset password email for a user given its username or e-mail.
 @see http://dev.socialidnow.com/index.php/POST_oauth/login/users/reset_password_email
 @param username Optional new username.
 @param email Optional e-mail password. At least one of these first two fields must be given.
 @param redirectUrl Optional url to redirect the user to inform the new password.
 @param from Optional sender email.
 @param subject Optional email subject.
 @param logoUrl Optional logo url to display in the email template.
 @param description Optional introductory message to the user.
 @param language Optional language configuration. Defaults to English.
 */
- (void) resetPassword:(NSString *)username
                 email:(NSString *)email
           redirectUrl:(NSString *)redirectUrl
                  from:(NSString *)from
               subject:(NSString *)subject
               logoUrl:(NSString *)logoUrl
           description:(NSString *)message
              language:(NSString *)language
               success:(void (^)(void))success
               failure:(SIDAPIFailureHandler)failure;

@end
