//
//  SIDAppSession.h
//  SocialID
//
//  Created by Renato Neves on 9/14/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import "SIDToken.h"

@interface SIDAppSession : NSObject

/**
 Returns true if there is a user currently logged in.
 */
+ (BOOL) isLoggedIn;

/**
 Log out by cleaning the user stored data.
 */
+ (void) logOut;

/**
 Returns the token from the currently logged in app.
 */
+ (SIDToken *) getToken;

/**
 Refreshes the currently login app token by creating a new one.
 @param success Callback when the request is successfull.
 @param failure Callback when the request is not successfull.
 */
+ (void) refreshToken:(void (^)(SIDToken *token))success
              failure:(void (^)(NSError *error))failure;

/**
 Handles a failure callback.
 If the token has expired it automatically creates a new one and executes the success callback.
 @param error The failure error response.
 @param success Callback executed if the failure callback was successfully handled.
 @param failure Callback executed if the failure callback continues failing.
 */
+ (void) handleFailure:(NSError *)error
               success:(void (^)())callback
               failure:(void (^)(NSError *error))failure;

@end