//
//  SIDFacebook.h
//  SocialID
//
//  Created by Renato Neves on 4/16/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <UIKit/UIKit.h>
#import "SIDProvider.h"

@interface SIDFacebook : NSObject <SIDProvider>

@property NSArray *permissions;

/**
 Returns the singleton object.
 */
+ (instancetype) sharedInstance;

/**
 Initializes the Facebook SDK and registers the provider in the SIDLogin.
 */
+ (void) initializeFacebook;

/**
 Set Facebook permissions.
 @param permissions An array of Facebook permissions.
 */
+ (void) setPermissions:(NSArray *)permissions;

/**
 Handles the didFinishLaunchingWithOptions app event.
 */
- (void) application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 During the Facebook login flow, your app passes control to the Facebook iOS app or Facebook in a mobile browser.
 After authentication, your app will be called back with the session information.
 */
- (BOOL) application:(UIApplication *)application
             openURL:(NSURL *)url
   sourceApplication:(NSString *)sourceApplication
          annotation:(id)annotation;

/**
 Performs the Social Login using the native Facebook login flow, returning the generated SIDUser or error.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInWithFields:(NSString *)fields
                 success:(void (^)(SIDUser *user))success
                 failure:(void (^)(NSError *error))failure;

/**
 Performs the Social Login using the native Facebook login flow, returning the generated SIDUser or error.
 @param permissions The permissions to be asked to the user.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInWithPermissions:(NSArray *)permissions
                       fields:(NSString *)fields
                      success:(void (^)(SIDUser *user))success
                      failure:(void (^)(NSError *error))failure;

/**
 Performs the Facebook native login flow, returning the generated access token or error.
 @param permissions The permissions to be asked to the user.
 @param success The callback in case of success. A NSString object is provided with the user access token.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInFacebook:(NSArray *)permissions
               success:(void (^)(NSString *accessToken))success
               failure:(void (^)(NSError *error))failure;

/**
 Logs the user out.
 */
- (void) logOut;

/**
 Create a SIDSignIn object given a Facebook access token.
 @param accessToken A Facebook access token.
 @param success The callback in case of success. A SIDSignIn object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) createTokenFromAccessToken:(NSString *)accessToken
                            success:(void (^)(SIDToken *token))success
                            failure:(void (^)(NSError *error))failure;

/**
 Returns the current FBSession access token.
 @return The access token.
 */
- (NSString *) accessToken;

@end
