//
//  SIDLinkedin.h
//  SocialID
//
//  Created by Dirceu Pereira Tiegs on 23/10/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <UIKit/UIKit.h>
#import "SIDProvider.h"

@interface SIDLinkedin : NSObject <SIDProvider>

@property NSString *callbackUrl;
@property NSString *consumerKey;
@property NSString *consumerSecret;
@property NSString *token;
@property NSString *tokenSecret;
@property NSString *oauthVerifier;
@property UIWebView *webView;
@property NSString *fields;
@property (copy, nonatomic) void (^success)(SIDUser *user);
@property (copy, nonatomic) void (^failure)(NSError *error);

/**
 Get singleton instance.
 */
+ (instancetype) sharedInstance;

/**
 Initializes the LinkedIn login and registers the provider in the SIDLogin.
 */
+ (void) initializeLinkedin;

/**
 Set the webview where the login flow will be performed.
 @param webview The webview.
 */
+ (void) setWebView:(UIWebView *)webview;

/**
 Performs the LinkedIn login flow in the configured webview, returning the generated SIDUser or error.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInWithFields:(NSString *)fields
                 success:(void (^)(SIDUser *user))success
                 failure:(void (^)(NSError *error))failure;

/**
 Create a SIDToken object given a Facebook access token.
 @param accessToken A LinkedIn access token.
 @param accessToken A LinkedIn access secret.
 @param success The callback in case of success. A SIDToken object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) createTokenFromAccessToken:(NSString *)accessToken
                       accessSecret:(NSString *)accessSecret
                            success:(void (^)(SIDToken *token))success
                            failure:(void (^)(NSError *error))failure;

/**
 Get LinkedIn access token given a verifier code.
 It also generates a SocialID Token and gets the user, executing the callbacks defined by logInWithFields:success:failure.
 @param verified LinkedIn verified code.
 */
- (void) getAccessTokenForVerifier:(NSString *)verifier;

@end
