//
//  SIDLogin.h
//  SocialID
//
//  Created by Renato Neves on 9/16/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "SIDUser.h"
#import "SIDProvider.h"

@interface SIDLogin : NSObject

@property NSString *userFields;
@property NSMutableDictionary *loginProviders;

/**
 Returns the singleton object.
 */
+ (instancetype) sharedInstance;

/**
 Sets the default user profile fields to be retrieved.
 @param fields The user profile fields.
 */
+ (void) setUserFields:(NSString *)fields;

/**
 Registers a login provider.
 @param provider Can be any of "facebook", "google", "linkedin" or "twitter".
 @param manager The provider shared instance.
 */
+ (void) registerLoginProvider:(NSString *)provider
                       manager:(NSObject<SIDProvider> *)manager;

/**
 Starts the given login provider flow.
 @param provider The provider name.
 @param success The success callback, with the SIDUser object.
 @param failure The failure callback, with the NSError object.
 */
+ (void) startLoginProvider:(NSString *)provider
                    success:(void (^)(SIDUser *user))success
                    failure:(void (^)(NSError *error))failure;

/**
 Creates and signs in the new user
 @param username Optional new username.
 @param email Optional e-mail. At least one of the optional fields must be given.
 @param password New password
 @param success The success callback, with the SIDUser object.
 @param failure The failure callback, with the NSError object.
 */
+ (void) createUser:(NSString *)username
              email:(NSString *)email
           password:(NSString *)password
            success:(void (^)(SIDUser *user))success
            failure:(void (^)(NSError *error))failure;

/**
 Signs in with existing user
 @param username Optional username.
 @param email Optional e-mail. Exactly one of the optional fields must be given.
 @param password User password
 @param success The success callback, with the SIDUser object.
 @param failure The failure callback, with the NSError object.
 */
+ (void) loginUser:(NSString *)username
             email:(NSString *)email
          password:(NSString *)password
           success:(void (^)(SIDUser *user))success
           failure:(void (^)(NSError *error))failure;

/**
 Updates currrent user data
 @param userData Dictionary with fields to be updated.
 @param success The success callback.
 @param failure The failure callback, with the NSError object.
 */
+ (void) updateUserData:(NSDictionary *)userData
                success:(void (^)(void))success
                failure:(void (^)(NSError *error))failure;

/**
 Sends a reset password email for a user given its username or e-mail.
 @see http://dev.socialidnow.com/index.php/POST_oauth/login/users/reset_password_email
 @param username Optional new username.
 @param email Optional e-mail. At least one of these first two fields must be given.
 @param redirectUrl Optional url to redirect the user to inform the new password.
 @param from Optional sender email.
 @param subject Optional email subject.
 @param logoUrl Optional logo url to display in the email template.
 @param description Optional introductory message to the user.
 @param language Optional language configuration. Defaults to English.
 */
+ (void) resetPassword:(NSString *)username
                 email:(NSString *)email
           redirectUrl:(NSString *)redirectUrl
                  from:(NSString *)from
               subject:(NSString *)subject
               logoUrl:(NSString *)logoUrl
           description:(NSString *)message
              language:(NSString *)language
               success:(void (^)(void))success
               failure:(void (^)(NSError *error))failure;

/**
 Handles the application:didFinishLaunchingWithOptions: AppDelegate method.
 @param application
 @param launchOptions
 */
+ (void) application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 Handles the application:openURL:sourceApplication:annotation AppDelegate method.
 @param application
 @param url
 @param sourceApplication
 @param annotation
 */
+ (BOOL) application:(UIApplication *)application
             openURL:(NSURL *)url
   sourceApplication:(NSString *)sourceApplication
          annotation:(id)annotation;

/**
 Logs the user out from socialid session and providers.
 */
+ (void) logOut;

@end
