//
//  SIDRequest.h
//  SocialID
//
//  Created by Renato Neves on 3/31/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface SIDRequest : NSObject

@property NSString *baseUrl;
@property NSString *authValue;

/**
 Initializes an object with the specified base URL.
 @param url The base URL for the HTTP client.
 @return The newly-initialized HTTP client
 */
- (instancetype) initWithBaseURL:(NSString *)baseURLString;

/**
 Sets the authorization field header with a Basic username and password.
 @param username The authorization username.
 @param password The authorization password.
 */
- (void) setAuthorizationHeaderFieldWithUsername:(NSString *)username
                                        password:(NSString *)password;

/**
 Sets the authorization field header with a Bearer token.
 @param token The Bearer token.
 */
- (void) setAuthorizationHeaderFieldWithBearer:(NSString *)token;

/**
 Performs a GET request.
 @param URLString The URL string used to create the request URL.
 @param parameters The parameters to be sent.
 @param success A block object to be executed when the request operation finishes successfully. This block has no return value and takes an argument: the response object.
 @param failure A block object to be executed when the request operation finishes unsuccessfully, or that finishes successfully, but encountered an error while parsing the response data. This block has no return value an argument: the error describing the network or parsing error that occurred.
 */
- (void) GET:(NSString *)URLString
  parameters:(NSDictionary *)parameters
     success:(void (^)(id responseObject))success
     failure:(void (^)(NSError *error))failure;

/**
 Performs a POST request.
 @param URLString The URL string used to create the request URL.
 @param parameters The parameters to be sent.
 @param headers The aditional headers to be sent.
 @param success A block object to be executed when the request operation finishes successfully. This block has no return value and takes an argument: the response object.
 @param failure A block object to be executed when the request operation finishes unsuccessfully, or that finishes successfully, but encountered an error while parsing the response data. This block has no return value an argument: the error describing the network or parsing error that occurred.
 */
- (void) POST:(NSString *)URLString
   parameters:(NSDictionary *)parameters
      headers:(NSDictionary *)headers
      success:(void (^)(id responseObject))success
      failure:(void (^)(NSError *error))failure;

/**
 Performs a POST request.
 @param URLString The URL string used to create the request URL.
 @param parameters The parameters to be sent.
 @param success A block object to be executed when the request operation finishes successfully. This block has no return value and takes an argument: the response object.
 @param failure A block object to be executed when the request operation finishes unsuccessfully, or that finishes successfully, but encountered an error while parsing the response data. This block has no return value an argument: the error describing the network or parsing error that occurred.
 */
- (void) POST:(NSString *)URLString
   parameters:(NSDictionary *)parameters
      success:(void (^)(id responseObject))success
      failure:(void (^)(NSError *error))failure;

/**
 Performs a PUT request.
 @param URLString The URL string used to create the request URL.
 @param parameters The parameters to be sent.
 @param success A block object to be executed when the request operation finishes successfully. This block has no return value and takes an argument: the response object.
 @param failure A block object to be executed when the request operation finishes unsuccessfully, or that finishes successfully, but encountered an error while parsing the response data. This block has no return value an argument: the error describing the network or parsing error that occurred.
 */
- (void) PUT:(NSString *)URLString
   parameters:(NSDictionary *)parameters
      success:(void (^)(id responseObject))success
      failure:(void (^)(NSError *error))failure;

/**
 Serialize a NSDictionary to send it as an HTTP request.
 @param params The dictionary of parameters
 */
+ (NSString *) serializeParams:(NSDictionary *)params;
@end
