//
//  SIDUserService.h
//  SocialID
//
//  Created by Renato Neves on 9/14/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import "SIDUser.h"
#import "SIDToken.h"

@interface SIDUserSession : NSObject

@property SIDUser *user;

/**
 Returns the singleton instance.
 */
+ (instancetype) sharedInstance;

/**
 Gets the current user with the default profile fields specified by SIDLogin.
 The request to the API is not performed if there is already a user stored in the shared instance.
 @param success Callback when the request is successfull.
 @param failure Callback when the request is not successfull.
 */
+ (void) getUser:(void (^)(SIDUser *user))success
         failure:(void (^)(NSError *error))failure;

/**
 Gets the current user with the specified profile fields.
 @param fields Profile fields.
 @param success Callback when the request is successfull.
 @param failure Callback when the request is not successfull.
 */
+ (void) getUserWithFields:(NSString *)fields
                   success:(void (^)(SIDUser *user))success
                   failure:(void (^)(NSError *error))failure;

/**
 Returns true if there is a user currently logged in.
 */
+ (BOOL) isLoggedIn;

/**
 Log out by cleaning the user stored data.
 */
+ (void) logOut;

/**
 Returns the token from the currently logged in user.
 */
+ (SIDToken *) getToken;

/**
 Refreshes the currently login user token.
 @param success Callback when the request is successfull.
 @param failure Callback when the request is not successfull.
 */
+ (void) refreshToken:(void (^)(SIDToken *token))success
              failure:(void (^)(NSError *error))failure;

/**
 Handles a failure callback.
 If the token has expired it automatically refreshes the token and executes the success callback.
 @param error The failure error response.
 @param success Callback executed if the failure callback was successfully handled.
 @param failure Callback executed if the failure callback continues failing.
 */
+ (void) handleFailure:(NSError *)error
               success:(void (^)())callback
               failure:(void (^)(NSError *error))failure;

@end